@@ -97,7 +97,7 @@ API Reference
 import re
 import warnings
 from textwrap import indent
-from typing import List, MutableMapping, Sequence, Union
+from typing import List, Sequence
 
 # 3rd party
 import ruamel.yaml as yaml
@@ -135,7 +135,7 @@ def parse_hooks(hooks: str) -> List[str]:
 
 
 class _BaseHook(TypedDict):
-	id: str  # noqa: A003
+	id: str  # noqa: A003  # pylint: disable=redefined-builtin
 
 
 class _Hook(_BaseHook, total=False):
