@@ -5,7 +5,7 @@
 General utility functions.
 """
 #
-#  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+#  Copyright © 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -58,6 +58,7 @@ __all__ = [
 		"escape_trailing__",
 		"code_repr",
 		"SphinxExtMetadata",
+		"SetupFunc",
 		"begin_generate",
 		"unknown_module_warning",
 		"filter_members_warning",
@@ -70,6 +71,7 @@ __all__ = [
 		"allow_subclass_add",
 		"NoMatchError",
 		"baseclass_is_private",
+		"metadata_add_version",
 		]
 
 #: Instance of :class:`apeye.url.RequestsURL` that points to the GitHub website.
@@ -269,10 +271,11 @@ def code_repr(obj: Any) -> str:
 
 class SphinxExtMetadata(TypedDict, total=False):
 	"""
-	:class:`typing.TypedDict` representing the metadata dictionary returned by Sphinx extensions' ``setup`` functions.
+	:class:`typing.TypedDict` representing the metadata dictionary returned by
+	Sphinx extensions' ``setup`` functions.
 
 	This is treated by Sphinx as metadata of the extension.
-	"""
+	"""  # noqa: D400
 
 	version: str
 	"""
@@ -309,6 +312,14 @@ class SphinxExtMetadata(TypedDict, total=False):
 	"""
 
 
+SetupFunc = Callable[[Sphinx], Optional["SphinxExtMetadata"]]
+"""
+Type annotation for Sphinx extensions' ``setup`` functions.
+
+.. versionadded:: 1.9.0
+"""
+
+
 def begin_generate(
 		documenter: Documenter,
 		real_modname: Optional[str] = None,
@@ -578,3 +589,25 @@ def baseclass_is_private(obj: Type) -> bool:
 	if hasattr(obj, "__bases__") and len(obj.__bases__) == 1:
 		return obj.__bases__[0].__name__.startswith("__")
 	return False
+
+
+def metadata_add_version(func: SetupFunc) -> SetupFunc:
+	"""
+	Internal decorator for Sphinx ``setup`` functions to add the ``sphinx-toolbox``
+	version number to the returned metadata dict.
+
+	.. versionadded:: 1.9.0
+
+	:param func:
+	"""  # noqa: D400
+
+	# this package
+	from sphinx_toolbox import __version__
+
+	@functools.wraps(func)
+	def wrapper(app: Sphinx):
+		ret = func(app) or {}
+		ret["version"] = __version__
+		return ret
+
+	return wrapper
